import{l as e,n as t,t as n,u as r}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{a as i}from"./socketActions-BHNJ_2Q0.js";import{Fn as a,Y as o,a as s,q as c,t as l}from"./lib-DqsS17DW.js";import{A as u}from"./index-DzPaEMae.js";l();var d=class extends r(u){get icons(){return Object.keys(i)}};d=t([e({})],d);var f=n(d,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(c,{attrs:{dense:e.$vuetify.breakpoint.smAndDown}},[t(o,{attrs:{cols:`12`}},[t(`h1`,[e._v(`All configured icons`)]),e._l(e.icons,function(n){return t(s,{key:n,staticClass:`d-inline-block`,attrs:{top:``},scopedSlots:e._u([{key:`activator`,fn:function({attrs:r,on:i}){return[t(a,e._g(e._b({staticClass:`ma-2`},`v-icon`,r,!1),i),[e._v(` $`+e._s(n)+` `)])]}}],null,!0)},[e._v(` `+e._s(n)+` `)])})],2)],1)},[],!1,null,null,null,null).exports;export{f as default};