import{l as e,n as t,t as n,u as r}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{Y as i,q as a,t as o}from"./lib-DqsS17DW.js";import{A as s}from"./index-DzPaEMae.js";import{n as c,t as l}from"./JobQueueCard-CI19zakw.js";o();var u=class extends r(s){get supportsJobQueue(){return this.$typedGetters[`server/componentSupport`](`job_queue`)}get hasQueuedJobs(){return this.supportsJobQueue&&this.$typedState.jobQueue.queuedJobs.length>0}};u=t([e({components:{JobsCard:c,JobQueueCard:l}})],u);var d=n(u,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(a,{attrs:{dense:e.$vuetify.breakpoint.smAndDown}},[t(i,{attrs:{cols:`12`,lg:e.hasQueuedJobs?8:void 0}},[t(`jobs-card`,{attrs:{fullscreen:``}})],1),e.hasQueuedJobs?t(i,{attrs:{cols:`12`,lg:`4`}},[t(`job-queue-card`,{attrs:{fullscreen:``}})],1):e._e()],1)},[],!1,null,null,null,null).exports;export{d as default};