import{i as e,n as t,r as n,t as r}from"./isArray-BfeOG1E2.js";var i=`[object Symbol]`;function a(e){return typeof e==`symbol`||t(e)&&n(e)==i}function o(e,t){for(var n=-1,r=e==null?0:e.length,i=Array(r);++n<r;)i[n]=t(e[n],n,e);return i}var s=1/0,c=e?e.prototype:void 0,l=c?c.toString:void 0;function u(e){if(typeof e==`string`)return e;if(r(e))return o(e,u)+``;if(a(e))return l?l.call(e):``;var t=e+``;return t==`0`&&1/e==-s?`-0`:t}function d(e){return e==null?``:u(e)}export{a as n,d as t};