import{o as e,t}from"./vue.runtime.esm-BGP6PPFT.js";import{l as n,n as r,t as i}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{Mt as a,t as o}from"./lib-DqsS17DW.js";import{l as s}from"./index-DzPaEMae.js";o(),e();var c=class extends t{camera=null;created(){let e=this.$route.params.cameraId,t=this.$typedGetters[`webcams/getWebcamById`](e);this.camera=t??null}};c=r([n({components:{CameraItem:s}})],c);var l=i(c,function(){var e=this,t=e._self._c;return e._self._setupProxy,e.camera?t(a,{staticClass:`overflow-hidden`},[t(`CameraItem`,{attrs:{camera:e.camera,fullscreen:``}})],1):e._e()},[],!1,null,null,null,null).exports;export{l as default};