import{l as e,n as t,t as n,u as r}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{Y as i,q as a,t as o}from"./lib-DqsS17DW.js";import{A as s,x as c}from"./index-DzPaEMae.js";import{t as l}from"./FileSystem-Cl4BbBoF.js";import{n as u,r as d,t as f}from"./DiskUsageCard-ByFun5jm.js";o();var p=class extends r(s){get hasGraphData(){return this.$typedState.charts.klipper!==void 0||this.$typedState.charts.moonraker!==void 0||this.$typedState.charts.memory!==void 0}get roots(){let e=[`logs`,`docs`,`config_examples`],t=[`gcodes`,`config`,`timelapse`,`timelapse_frames`],n=this.$typedState.server.info.registered_directories||[];for(let r of n)!t.includes(r)&&!e.includes(r)&&e.push(r);return e}};p=t([e({components:{FileSystem:l,SystemOverviewCard:d,SystemUsageCard:u,DiskUsageCard:f}})],p);var m=n(p,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(a,{attrs:{dense:e.$vuetify.breakpoint.smAndDown}},[t(i,{attrs:{cols:`12`,md:`6`}},[t(c,{staticClass:`mb-2 mb-md-4`,attrs:{title:e.$t(`app.general.title.config_files`),icon:`$codeJson`,"help-tooltip":e.$t(`app.general.tooltip.file_browser_help`)}},[t(`file-system`,{staticClass:`full-screen`,attrs:{roots:[`config`],name:`configure`,"bulk-actions":``}})],1)],1),t(i,{attrs:{cols:`12`,md:`6`}},[t(c,{staticClass:`mb-2 mb-md-4`,attrs:{title:e.$t(`app.general.title.other_files`),icon:`$files`,"help-tooltip":e.$t(`app.general.tooltip.file_browser_configuration_help`)}},[t(`file-system`,{staticClass:`full-screen`,attrs:{roots:e.roots,name:`configure`}})],1)],1)],1)},[],!1,null,`5506b5d7`,null,null).exports;export{m as default};