.console-command[data-v-bd880195]{font-family:monospace}.presets-table table>tbody>tr>td[data-v-6314dddc]{vertical-align:top;padding-top:8px;padding-bottom:8px}ol.commit-history[data-v-4a1c7358]{border:thin solid #ffffff1f;border-radius:6px;margin:0;padding:0;list-style-type:none}ol.commit-history li[data-v-4a1c7358]{border-bottom:thin solid #ffffff1f;flex:1 0 auto;justify-content:space-between;align-items:center;padding:8px 16px;display:flex}ol.commit-history li[data-v-4a1c7358]:hover{background-color:#ffffff06}ol.commit-history li[data-v-4a1c7358]:last-child{border:none}.commit-table[data-v-4a1c7358]{border-bottom:thin solid #ffffff1f;border-radius:6px}[data-v-4a1c7358] .v-timeline-item__dot{box-shadow:none!important}[data-v-a26c43ce] canvas{background:#fff;padding:10px;display:block}
