import{o as e,t}from"./vue.runtime.esm-BGP6PPFT.js";import{l as n,n as r,s as i,t as a}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{Fn as o,Sn as s,Wn as c,t as l}from"./lib-DqsS17DW.js";import{P as u}from"./index-DzPaEMae.js";l(),e();var d=class extends t{collapsed;menuIcon;disabled;get hasDefaultSlot(){return!!this.$slots.default}};r([i({type:Boolean})],d.prototype,`collapsed`,void 0),r([i({type:String,default:`$menu`})],d.prototype,`menuIcon`,void 0),r([i({type:Boolean})],d.prototype,`disabled`,void 0),d=r([n({inheritAttrs:!1})],d);var f=a(d,function(){var e=this,t=e._self._c;return e._self._setupProxy,e.collapsed?t(s,{attrs:{transition:`slide-y-transition`,left:``,"offset-y":``,disabled:e.disabled,"close-on-content-click":!1},scopedSlots:e._u([{key:`activator`,fn:function({on:n,attrs:r}){return[t(u,e._g(e._b({attrs:{icon:``,disabled:e.disabled}},`app-btn`,r,!1),n),[t(o,{attrs:{dense:``}},[e._v(` `+e._s(e.menuIcon)+` `)])],1)]}}])},[t(c,{staticClass:`pa-2`,attrs:{elevation:`0`}},[e._t(`default`)],2)],1):t(`div`,{staticClass:`d-inline-block`},[e._t(`default`)],2)},[],!1,null,null,null,null).exports;export{f as t};