import{o as e,t}from"./vue.runtime.esm-BGP6PPFT.js";import{l as n,n as r,t as i}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{Y as a,q as o,t as s}from"./lib-DqsS17DW.js";import{t as c}from"./GcodePreviewCard-BISVp6sA.js";s(),e();var l=class extends t{};l=r([n({components:{GcodePreviewCard:c}})],l);var u=i(l,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(o,{attrs:{dense:e.$vuetify.breakpoint.smAndDown}},[t(a,{attrs:{cols:`12`}},[t(`GcodePreviewCard`,{attrs:{fullscreen:``}})],1)],1)},[],!1,null,null,null,null).exports;export{u as default};