.full-screen[data-v-a1ba2baa]{max-height:calc(100svh - 190px)}.partial-screen[data-v-a1ba2baa]{height:400px}.theme--dark[data-v-8909519b] .v-simple-checkbox .v-icon{color:#ffffff40}.filesystem-wrapper[data-v-13a58738],.file-system[data-v-13a58738],.file-system[data-v-13a58738] .app-draggable,.file-system[data-v-13a58738] .v-data-table{flex-direction:column;height:100%;display:flex;overflow:hidden}.full-screen[data-v-4c66f0c8]{max-height:calc(100svh - 190px)}.partial-screen[data-v-4c66f0c8]{max-height:400px}
