.v-stepper[data-v-5358e569]{background:0 0}.jv-container>.jv-code{padding:0!important}.jv-container.jv-dark{color:#fffc!important;background:0 0!important}.jv-container.jv-dark .jv-item.jv-object,.jv-container.jv-dark .jv-item.jv-array,.jv-container.jv-dark .jv-key{color:#fffc!important}.jv-container.jv-dark .jv-ellipsis{color:#ffffff80!important;background-color:#fff3!important}.v-stepper__header>.v-stepper__step[data-v-7b2dfb70]{padding-top:22px;padding-bottom:22px}.v-stepper[data-v-bcb2e639]{background:0 0}.flip-list-move[data-v-e0180ecc]{transition:transform .5s}.no-move[data-v-e0180ecc]{transition:transform}.app-draggable__ghost[data-v-e0180ecc]{opacity:.5;background:#ccc}.list-group[data-v-e0180ecc]{flex:auto}.list-group span[data-v-e0180ecc]{flex-direction:column;height:100%;min-height:50vh;display:flex}@media only screen and (width<=959.98px){.list-group span[data-v-e0180ecc]{min-height:auto}}.drag .list-group[data-v-e0180ecc]{border:thin dashed #ffffff1f;padding:6px}
