.color-input div[data-v-ffcc9c69]{text-align:center;margin:0 2px}.theme--light .color-input div[data-v-ffcc9c69]:not(:first-child){color:#00000073}.theme--dark .color-input div[data-v-ffcc9c69]:not(:first-child){color:#ffffff73}[data-v-ffcc9c69] .v-text-field__slot input{text-align:center}[data-v-ffcc9c69] .v-input--dense .v-input__slot{min-height:32px!important}
