[data-v-e5275521] .v-breadcrumbs__item:not(.v-breadcrumbs__item--disabled){cursor:pointer}[data-v-e5275521] .v-breadcrumbs__item:not(.v-breadcrumbs__item--disabled):hover{text-decoration:underline}[data-v-6c331dfd] .v-list-item--active:before{opacity:0}[data-v-6c331dfd] .v-list-item--active:hover:before{opacity:.08}.theme--dark[data-v-57777f09] .v-simple-checkbox .v-icon{color:#ffffff40}.app-text-field .btn-copy[data-v-7b4d2bcd]{margin-top:-8px;margin-right:-2px}.app-text-field .icon-copy[data-v-7b4d2bcd]{position:absolute}[data-v-368bd35d] .v-expansion-panel:before{box-shadow:none}[data-v-f1d79fdb]{min-width:100%;height:calc(100% - 48px)}[data-v-f1d79fdb] .spinner{justify-content:center;align-items:center;height:100vh;display:flex}[data-v-a8c9a776]{resize:none;min-width:100%;font-family:monospace;font-size:1rem;height:calc(100% - 48px)!important;font-weight:100!important}video[data-v-37a59b1e],img[data-v-37a59b1e]{max-width:100%;max-height:calc(90vh - 144px)}[data-v-37a59b1e] .markdown-container img{max-width:100%!important}[data-v-37a59b1e] .markdown-container table{border-collapse:collapse}[data-v-37a59b1e] .markdown-container table th,[data-v-37a59b1e] .markdown-container table td{border:1px solid;padding:2px 6px}[data-v-37a59b1e] .markdown-container pre>code{display:block}[data-v-37a59b1e] .markdown-container *{margin-bottom:1em}.filesystem-wrapper[data-v-8a5776c2],.file-system[data-v-8a5776c2],.file-system[data-v-8a5776c2] .v-data-table{flex-direction:column;height:100%;display:flex;overflow:hidden}.v-text-field .v-select__slot .v-select__selection--comma[data-v-8a5776c2]{min-width:min-content}.dragOverlay.v-overlay--active[data-v-8a5776c2]{border:3px dashed #616161}[data-v-8a5776c2] .dragOverlay>.v-overlay__content{width:100%}
