[data-v-6a050874] .v-input__slot{cursor:default!important;outline:none!important;padding:0!important}[data-v-6a050874] .v-input__slot fieldset{top:0!important}.layer[data-v-51df6e4b]{filter:brightness(140%)}.layer>path[data-v-51df6e4b]{stroke-linecap:round;stroke-linejoin:round}.layer .partOutline[data-v-51df6e4b]{filter:opacity(60%);stroke-width:.5px}.layer .partIcon[data-v-51df6e4b]{fill-opacity:.15;stroke-width:.5px}.layer .partIcon .hitarea[data-v-51df6e4b]{pointer-events:all;z-index:-1}.layer:not(.partExcluded) .partIcon[data-v-51df6e4b]:hover{fill-opacity:.5}.layer.partExcluded[data-v-51df6e4b]{fill:var(--v-error-base);stroke:var(--v-error-base)}.layer.partIncluded[data-v-51df6e4b]{fill:var(--v-success-base);stroke:var(--v-success-base)}.layer.partCurrent[data-v-51df6e4b]{fill:var(--v-info-base);stroke:var(--v-info-base)}.theme--light .layer[data-v-51df6e4b]{filter:brightness(90%)}.theme--light.gcode-preview-tool .extruder-color[data-v-477aa936]{border-color:#000000de}.theme--dark.gcode-preview-tool .extruder-color[data-v-477aa936]{border-color:#fffc}.gcode-preview-tool[data-v-477aa936]{border:1px solid #0000;border-radius:6px;align-items:center;padding:0 4px;display:inline-flex}.gcode-preview-tool.active[data-v-477aa936],.gcode-preview-tool.active .extruder-color[data-v-477aa936]{border-color:#fffc}.gcode-preview-tool .extruder-color[data-v-477aa936]{border-style:solid;border-width:1px;border-radius:50%;width:15px;height:15px}.preview-options[data-v-8f692a20],.preview-name[data-v-8f692a20]{background:#000000bf;padding:2px 6px;font-weight:100;position:absolute}.preview-options[data-v-8f692a20]{border-bottom-right-radius:4px;top:0}.preview-name[data-v-8f692a20]{border-top-right-radius:4px;bottom:0}.theme--light .preview-options[data-v-8f692a20],.theme--light .preview-name[data-v-8f692a20]{background:#ffffffbf}[data-v-8f692a20] .v-input__slot{aspect-ratio:1;max-height:calc(100svh - 398px);overflow:hidden;min-height:250px!important}[data-v-8f692a20] .v-input__slot svg{shape-rendering:geometricprecision}[data-v-8f692a20] .v-input__slot svg .layer>path{fill:none;stroke-linecap:round;stroke-linejoin:round}
