import{o as e,t}from"./vue.runtime.esm-BGP6PPFT.js";import{l as n,n as r,t as i}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{Qt as a,en as o,fn as s,mn as c,t as l}from"./lib-DqsS17DW.js";l(),e();var u=class extends t{get isVisible(){return!this.$vuetify.breakpoint.mobile}get items(){return[{name:this.$t(`app.setting.title.general`),hash:`#general`,visible:!0},{name:this.$t(`app.setting.title.warnings`),hash:`#warnings`,visible:!0},{name:this.$t(`app.setting.title.theme`),hash:`#theme`,visible:!0},{name:this.$t(`app.setting.title.authentication`),hash:`#auth`,visible:!0},{name:this.$t(`app.setting.title.console`),hash:`#console`,visible:!0},{name:this.$t(`app.setting.title.file_browser`),hash:`#browser`,visible:!0},{name:this.$t(`app.setting.title.file_editor`),hash:`#editor`,visible:!0},{name:this.$t(`app.setting.title.macros`),hash:`#macros`,visible:!0},{name:this.$tc(`app.setting.title.camera`,2),hash:`#camera`,visible:!0},{name:this.$t(`app.setting.title.tool`),hash:`#toolhead`,visible:!0},{name:this.$t(`app.setting.title.thermal_presets`),hash:`#presets`,visible:!0},{name:this.$t(`app.setting.title.gcode_preview`),hash:`#gcodePreview`,visible:!0},{name:this.$t(`app.general.title.timelapse`),hash:`#timelapse`,visible:this.supportsTimelapse},{name:this.$t(`app.mmu.title.headline`),hash:`#mmu`,visible:this.supportsMmu},{name:this.$t(`app.spoolman.title.spoolman`),hash:`#spoolman`,visible:this.supportsSpoolman},{name:this.$t(`app.version.title`),hash:`#versions`,visible:this.supportsVersions}]}get supportsVersions(){return this.$typedGetters[`server/componentSupport`](`update_manager`)}get supportsTimelapse(){return this.$typedGetters[`server/componentSupport`](`timelapse`)}get supportsSpoolman(){return this.$typedGetters[`server/componentSupport`](`spoolman`)}get supportsMmu(){return this.$typedState.printer.printer.mmu!=null}};u=r([n({})],u);var d=i(u,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(c,{staticClass:`grow pt-0`,attrs:{dense:``,width:`180`,color:e.$vuetify.theme.dark?`#1E1E20`:`#FFFFFF`}},[e._l(e.items,function(n){return[n.visible?t(s,{key:n.name,attrs:{to:{name:`settings`,hash:n.hash},exact:!1,link:``}},[t(a,[t(o,[e._v(e._s(n.name))])],1)],1):e._e()]})],2)},[],!1,null,null,null,null).exports;export{d as default};