var e={app:{bedmesh:{label:{mesh_matrix:`Mesh matrix`,base:`bas`,flat_surface:`Visa platt plan`,profile_name:`Profilnamn`,scale:`Färgskala`,wireframe:`Trådram`,active:`aktiv`,remove_profile:`Ta bort %{name} profil`},msg:{hint:`Om det sparas som något annat än %{name}, kan du välja att också ta bort %{name} profilen`}},afc:{AfcSettings:`AFC-Inställningar`,BufferDisabled:`Buffer inte aktiv`,BrushNozzle:`Borstmunstycke`,BypassActive:`Filament som laddats i bypassverktygsbyten är inaktiverade!`,Calibrate:`Kalibrera`,Cancel:`Avbryt`,CaptureTd:`Fånga TD`,DebugJson:`Felsöka JSON`,Detected:`Upptäckt`,EjectFilament:`Mata ut filament`,Ejecting:`Matar ut`,Empty:`Tömma`,Error:`Fel`,FilamentForLane:`Filament för {name}`,Functions:`Funktioner`,Headline:`AFC`,Hub:`Hubb`}}};export{e as default};