import{a as e,l as t,n,t as r,u as i}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{t as a}from"./camera-DKiOc18c.js";var o=class extends i(a){cameraIframe;cameraIFrameSource=``;startPlayback(){this.updateStatus(`connecting`);let e=this.buildAbsoluteUrl(this.camera.stream_url||``).toString();this.cameraIFrameSource=e,this.updateRawCameraUrl(e)}stopPlayback(){this.updateStatus(`disconnected`),this.cameraIFrameSource=``,this.cameraIframe.src=``}};n([e(`streamingElement`)],o.prototype,`cameraIframe`,void 0),o=n([t({})],o);var s=r(o,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(`iframe`,{ref:`streamingElement`,staticStyle:{border:`none`,width:`100%`},style:{"aspect-ratio":(e.camera.aspect_ratio||`16:9`).replace(`:`,`/`),...e.cameraStyle},attrs:{src:e.cameraIFrameSource},on:{load:function(t){return e.updateStatus(`connected`)},error:function(t){return e.updateStatus(`error`)}}})},[],!1,null,null,null,null).exports;export{s as default};