import{o as e,t}from"./vue.runtime.esm-BGP6PPFT.js";import{i as n,l as r,n as i,s as a,t as o,u as s}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{Fn as c,Sn as l,Wn as u,a as d,t as f,wn as p}from"./lib-DqsS17DW.js";import{P as m,T as h}from"./index-DzPaEMae.js";import{t as g}from"./AppNamedSlider-GqB9_9vm.js";f(),e();var _=class extends t{thumbnailSize;disabled};i([n({type:Number,required:!0})],_.prototype,`thumbnailSize`,void 0),i([a({type:Boolean})],_.prototype,`disabled`,void 0),_=i([r({})],_);var v=o(_,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(l,{attrs:{bottom:``,left:``,"offset-y":``,transition:`slide-y-transition`,"min-width":`150`,"close-on-content-click":!1},scopedSlots:e._u([{key:`activator`,fn:function({on:n,attrs:r}){return[t(d,{attrs:{bottom:``},scopedSlots:e._u([{key:`activator`,fn:function({on:i}){return[t(m,e._g(e._b({attrs:{disabled:e.disabled,icon:``,text:``}},`app-btn`,r,!1),{...i,...n}),[t(c,[e._v(` $imageSizeSelectLarge `)])],1)]}}],null,!0)},[t(`span`,[e._v(e._s(e.$t(`app.general.btn.thumbnail_size`)))])])]}}])},[t(u,{staticClass:`pa-2`},[t(g,{staticClass:`ma-1`,attrs:{label:e.$t(`app.general.label.thumbnail_size`),min:32,max:192,step:16,"reset-value":32,suffix:`px`},model:{value:e.thumbnailSize,callback:function(t){e.thumbnailSize=t},expression:`thumbnailSize`}})],1)],1)},[],!1,null,null,null,null).exports;e();var y=class extends t{temps};i([a({type:Array,required:!0})],y.prototype,`temps`,void 0),y=i([r({inheritAttrs:!1})],y);var b=y;f();var x=o(b,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(`div`,e._l(e.temps,function(n,r){return t(p,e._g(e._b({key:r,class:{"ms-1":r>0},attrs:{small:``}},`v-chip`,e.$attrs,!1),e.$listeners),[e._v(` `+e._s(n)),t(`small`,[e._v(`°C`)])])}),1)},[],!1,null,null,null,null).exports,S=class extends s(h){job;get icon(){switch(this.job.status){case`completed`:return`$checkedCircle`;case`printing`:case`in_progress`:return`$inProgress`;case`cancelled`:case`interrupted`:return`$cancelled`;default:return`$warning`}}get state(){switch(this.job.status){case`cancelled`:case`error`:case`interrupted`:case`server_exit`:return`error`;case`klippy_shutdown`:case`klippy_disconnect`:return`warning`;case`completed`:return`success`;case`printing`:case`in_progress`:return`info`;default:return`success`}}};i([a({type:Object,required:!0})],S.prototype,`job`,void 0),S=i([r({})],S);var C=S;f();var w=o(C,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(d,{attrs:{top:``},scopedSlots:e._u([{key:`activator`,fn:function({on:n,attrs:r}){return[t(c,e._g(e._b({staticClass:`mr-1`,attrs:{small:``,color:e.job.exists?e.state:`secondary`}},`v-icon`,r,!1),n),[e._v(` `+e._s(e.icon)+` `)])]}}])},[t(`span`,[e._v(e._s(e.$filters.prettyCase(e.job.status)))])])},[],!1,null,null,null,null).exports;export{x as n,v as r,w as t};