import{a as e,l as t,n,t as r,u as i}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{t as a}from"./browser-1D2tZwAR.js";import{t as o}from"./camera-DKiOc18c.js";var s=class extends i(o){cameraVideo;cameraVideoSource=``;get autoRaiseFrameEvent(){return!1}startPlayback(){try{this.updateStatus(`connecting`);let e=this.buildAbsoluteUrl(this.camera.stream_url||``).toString();this.cameraVideoSource=e,this.updateRawCameraUrl(e)}catch(e){a.error(`[IpstreamCamera] failed to start playback "${this.camera.name}"`,e)}}stopPlayback(){this.updateStatus(`disconnected`),this.cameraVideoSource=``,this.cameraVideo.src=``}};n([e(`streamingElement`)],s.prototype,`cameraVideo`,void 0),s=n([t({})],s);var c=r(s,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(`video`,{ref:`streamingElement`,style:e.cameraStyle,attrs:{autoplay:``,disablePictureInPicture:``,playsinline:``,muted:``,crossorigin:e.crossorigin,src:e.cameraVideoSource},domProps:{muted:!0},on:{play:function(t){return e.updateStatus(`connected`)},error:function(t){return e.updateStatus(`error`)}}})},[],!1,null,null,null,null).exports;export{c as default};