.thumbnail[data-v-3d5f9346]{pointer-events:none;width:100%}.render-progress[data-v-3d5f9346]{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)}.full-screen[data-v-d084831c]{max-height:calc(100svh - 190px)}
