import{o as e,t}from"./vue.runtime.esm-BGP6PPFT.js";import{l as n,n as r,s as i,t as a}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{t as o}from"./get-DprfYscH.js";import{Y as s,t as c}from"./lib-DqsS17DW.js";import{t as l}from"./AppChart-BuLa4rIy.js";c(),e();var u=class extends t{data;options;labels;get hasData(){return Array.isArray(this.data)&&this.data.length>0}isEmpty(e){return e==null||e===``||Array.isArray(e)&&e.length===0}get items(){let e=this.data[this.data.length-1];return this.labels.map(t=>{let n=o(e,t.value),r=typeof n==`number`&&n!==0?n.toFixed(2):n;return{label:t,value:this.isEmpty(n)?`--`:`${r}${t.suffix??``}`}})}};r([i({type:Array,required:!0})],u.prototype,`data`,void 0),r([i({type:Object,required:!0})],u.prototype,`options`,void 0),r([i({type:Array,required:!0})],u.prototype,`labels`,void 0),u=r([n({})],u);var d=a(u,function(){var e=this,t=e._self._c;return e._self._setupProxy,e.hasData?t(s,{staticClass:`chart-wrapper`,attrs:{cols:`4`}},[t(l,{attrs:{data:e.data,options:e.options,height:`120px`}}),t(`div`,{staticClass:`chart-label-wrapper`},e._l(e.items,function({label:n,value:r}){return t(`div`,{key:n.value,staticClass:`chart-label`},[t(`span`,[e._v(e._s(n.text))]),t(`span`,[e._v(e._s(r))])])}),0)],1):e._e()},[],!1,null,`a12f73e3`,null,null).exports;export{d as t};