import{o as e,t}from"./vue.runtime.esm-BGP6PPFT.js";import{l as n,n as r,t as i}from"./_plugin-vue2_normalizer-Vm4EDAeQ.js";import{Y as a,q as o,t as s}from"./lib-DqsS17DW.js";import{P as c}from"./index-DzPaEMae.js";s(),e();var l=class extends t{};l=r([n({})],l);var u=i(l,function(){var e=this,t=e._self._c;return e._self._setupProxy,t(o,{attrs:{dense:e.$vuetify.breakpoint.smAndDown,justify:`center`,align:`center`}},[t(a,[t(`center`,[t(`div`,{staticClass:`text-h5`},[e._v(` `+e._s(e.$t(`app.general.title.not_found`))+` `)]),t(c,{staticClass:`mt-5`,attrs:{to:`/`}},[e._v(` `+e._s(e.$t(`app.general.btn.return_dashboard`))+` `)])],1)],1)],1)},[],!1,null,null,null,null).exports;export{u as default};